==> kubernetes-model-1.0.58-sources.jar: annotations/io/fabric8/openshift/api/model/RoleBindingFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class RoleBindingFluentImpl<A extends RoleBindingFluent<A>> extends BaseFluent<A> implements RoleBindingFluent<A>{

    private String apiVersion;
    private List<String> groupNames = new ArrayList<String>();
    private String kind;
    private VisitableBuilder<? extends ObjectMeta,?> metadata;
    private VisitableBuilder<? extends ObjectReference,?> roleRef;
    private List<VisitableBuilder<? extends ObjectReference,?>> subjects =  new ArrayList<VisitableBuilder<? extends ObjectReference,?>>();
    private List<String> userNames = new ArrayList<String>();

    public RoleBindingFluentImpl(){
    }
    public RoleBindingFluentImpl(RoleBinding instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withGroupNames(instance.getGroupNames()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withRoleRef(instance.getRoleRef()); 
            this.withSubjects(instance.getSubjects()); 
            this.withUserNames(instance.getUserNames()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public A addToGroupNames(String... items){
            for (String item : items) {this.groupNames.add(item);} return (A)this;
    }

    public A removeFromGroupNames(String... items){
            for (String item : items) {this.groupNames.remove(item);} return (A)this;
    }

    public List<String> getGroupNames(){
            return this.groupNames;
    }

    public A withGroupNames(List<String> groupNames){
            this.groupNames.clear();
            if (groupNames != null) {for (String item : groupNames){this.addToGroupNames(item);}} return (A) this;
    }

    public A withGroupNames(String... groupNames){
            this.groupNames.clear(); if (groupNames != null) {for (String item :groupNames){ this.addToGroupNames(item);}} return (A) this;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public RoleBindingFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public RoleBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public RoleBindingFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ObjectReference getRoleRef(){
            return this.roleRef!=null?this.roleRef.build():null;
    }

    public A withRoleRef(ObjectReference roleRef){
            if (roleRef!=null){ this.roleRef= new ObjectReferenceBuilder(roleRef); _visitables.add(this.roleRef);} return (A) this;
    }

    public RoleBindingFluent.RoleRefNested<A> withNewRoleRef(){
            return new RoleRefNestedImpl();
    }

    public RoleBindingFluent.RoleRefNested<A> withNewRoleRefLike(ObjectReference item){
            return new RoleRefNestedImpl(item);
    }

    public RoleBindingFluent.RoleRefNested<A> editRoleRef(){
            return withNewRoleRefLike(getRoleRef());
    }

    public A addToSubjects(ObjectReference... items){
            for (ObjectReference item : items) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.add(builder);this.subjects.add(builder);} return (A)this;
    }

    public A removeFromSubjects(ObjectReference... items){
            for (ObjectReference item : items) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.remove(builder);this.subjects.remove(builder);} return (A)this;
    }

    public List<ObjectReference> getSubjects(){
            return build(subjects);
    }

    public A withSubjects(List<ObjectReference> subjects){
            this.subjects.clear();
            if (subjects != null) {for (ObjectReference item : subjects){this.addToSubjects(item);}} return (A) this;
    }

    public A withSubjects(ObjectReference... subjects){
            this.subjects.clear(); if (subjects != null) {for (ObjectReference item :subjects){ this.addToSubjects(item);}} return (A) this;
    }

    public RoleBindingFluent.SubjectsNested<A> addNewSubject(){
            return new SubjectsNestedImpl();
    }

    public RoleBindingFluent.SubjectsNested<A> addNewSubjectLike(ObjectReference item){
            return new SubjectsNestedImpl(item);
    }

    public A addToUserNames(String... items){
            for (String item : items) {this.userNames.add(item);} return (A)this;
    }

    public A removeFromUserNames(String... items){
            for (String item : items) {this.userNames.remove(item);} return (A)this;
    }

    public List<String> getUserNames(){
            return this.userNames;
    }

    public A withUserNames(List<String> userNames){
            this.userNames.clear();
            if (userNames != null) {for (String item : userNames){this.addToUserNames(item);}} return (A) this;
    }

    public A withUserNames(String... userNames){
            this.userNames.clear(); if (userNames != null) {for (String item :userNames){ this.addToUserNames(item);}} return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RoleBindingFluentImpl that = (RoleBindingFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (groupNames != null ? !groupNames.equals(that.groupNames) :that.groupNames != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (roleRef != null ? !roleRef.equals(that.roleRef) :that.roleRef != null) return false;
            if (subjects != null ? !subjects.equals(that.subjects) :that.subjects != null) return false;
            if (userNames != null ? !userNames.equals(that.userNames) :that.userNames != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RoleBindingFluent.MetadataNested<N>> implements RoleBindingFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) RoleBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class RoleRefNestedImpl<N> extends ObjectReferenceFluentImpl<RoleBindingFluent.RoleRefNested<N>> implements RoleBindingFluent.RoleRefNested<N>,Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            RoleRefNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
            RoleRefNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
    
    public N endRoleRef(){
            return and();
    }
    public N and(){
            return (N) RoleBindingFluentImpl.this.withRoleRef(builder.build());
    }

}
    public class SubjectsNestedImpl<N> extends ObjectReferenceFluentImpl<RoleBindingFluent.SubjectsNested<N>> implements RoleBindingFluent.SubjectsNested<N>,Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            SubjectsNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
            SubjectsNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
    
    public N and(){
            return (N) RoleBindingFluentImpl.this.addToSubjects(builder.build());
    }
    public N endSubject(){
            return and();
    }

}


}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/RoleBindingFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import lombok.ToString;

public class RoleBindingFluentImpl<A extends RoleBindingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements RoleBindingFluent<A>{

    private String apiVersion;
    private List<String> groupNames = new ArrayList<String>();
    private String kind;
    private VisitableBuilder<? extends ObjectMeta,?> metadata;
    private VisitableBuilder<? extends ObjectReference,?> roleRef;
    private List<VisitableBuilder<? extends ObjectReference,?>> subjects =  new ArrayList<VisitableBuilder<? extends ObjectReference,?>>();
    private List<String> userNames = new ArrayList<String>();

    public RoleBindingFluentImpl(){
    }
    public RoleBindingFluentImpl(RoleBinding instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withGroupNames(instance.getGroupNames()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withRoleRef(instance.getRoleRef()); 
            this.withSubjects(instance.getSubjects()); 
            this.withUserNames(instance.getUserNames()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public A addToGroupNames(String... items){
            for (String item : items) {this.groupNames.add(item);} return (A)this;
    }

    public A removeFromGroupNames(String... items){
            for (String item : items) {this.groupNames.remove(item);} return (A)this;
    }

    public List<String> getGroupNames(){
            return this.groupNames;
    }

    public A withGroupNames(List<String> groupNames){
            this.groupNames.clear();
            if (groupNames != null) {for (String item : groupNames){this.addToGroupNames(item);}} return (A) this;
    }

    public A withGroupNames(String... groupNames){
            this.groupNames.clear(); if (groupNames != null) {for (String item :groupNames){ this.addToGroupNames(item);}} return (A) this;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public RoleBindingFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public RoleBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public RoleBindingFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public RoleBindingFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public RoleBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public ObjectReference getRoleRef(){
            return this.roleRef!=null?this.roleRef.build():null;
    }

    public A withRoleRef(ObjectReference roleRef){
            _visitables.remove(this.roleRef);
            if (roleRef!=null){ this.roleRef= new ObjectReferenceBuilder(roleRef); _visitables.add(this.roleRef);} return (A) this;
    }

    public RoleBindingFluent.RoleRefNested<A> withNewRoleRef(){
            return new RoleRefNestedImpl();
    }

    public RoleBindingFluent.RoleRefNested<A> withNewRoleRefLike(ObjectReference item){
            return new RoleRefNestedImpl(item);
    }

    public RoleBindingFluent.RoleRefNested<A> editRoleRef(){
            return withNewRoleRefLike(getRoleRef());
    }

    public RoleBindingFluent.RoleRefNested<A> editOrNewRoleRef(){
            return withNewRoleRefLike(getRoleRef() != null ? getRoleRef(): new ObjectReferenceBuilder().build());
    }

    public RoleBindingFluent.RoleRefNested<A> editOrNewRoleRefLike(ObjectReference item){
            return withNewRoleRefLike(getRoleRef() != null ? getRoleRef(): item);
    }

    public A addToSubjects(ObjectReference... items){
            for (ObjectReference item : items) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.add(builder);this.subjects.add(builder);} return (A)this;
    }

    public A removeFromSubjects(ObjectReference... items){
            for (ObjectReference item : items) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.remove(builder);this.subjects.remove(builder);} return (A)this;
    }

    public List<ObjectReference> getSubjects(){
            return build(subjects);
    }

    public A withSubjects(List<ObjectReference> subjects){
            _visitables.removeAll(this.subjects);
            this.subjects.clear();
            if (subjects != null) {for (ObjectReference item : subjects){this.addToSubjects(item);}} return (A) this;
    }

    public A withSubjects(ObjectReference... subjects){
            this.subjects.clear(); if (subjects != null) {for (ObjectReference item :subjects){ this.addToSubjects(item);}} return (A) this;
    }

    public RoleBindingFluent.SubjectsNested<A> addNewSubject(){
            return new SubjectsNestedImpl();
    }

    public RoleBindingFluent.SubjectsNested<A> addNewSubjectLike(ObjectReference item){
            return new SubjectsNestedImpl(item);
    }

    public A addToUserNames(String... items){
            for (String item : items) {this.userNames.add(item);} return (A)this;
    }

    public A removeFromUserNames(String... items){
            for (String item : items) {this.userNames.remove(item);} return (A)this;
    }

    public List<String> getUserNames(){
            return this.userNames;
    }

    public A withUserNames(List<String> userNames){
            this.userNames.clear();
            if (userNames != null) {for (String item : userNames){this.addToUserNames(item);}} return (A) this;
    }

    public A withUserNames(String... userNames){
            this.userNames.clear(); if (userNames != null) {for (String item :userNames){ this.addToUserNames(item);}} return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RoleBindingFluentImpl that = (RoleBindingFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (groupNames != null ? !groupNames.equals(that.groupNames) :that.groupNames != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (roleRef != null ? !roleRef.equals(that.roleRef) :that.roleRef != null) return false;
            if (subjects != null ? !subjects.equals(that.subjects) :that.subjects != null) return false;
            if (userNames != null ? !userNames.equals(that.userNames) :that.userNames != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RoleBindingFluent.MetadataNested<N>> implements RoleBindingFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) RoleBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class RoleRefNestedImpl<N> extends ObjectReferenceFluentImpl<RoleBindingFluent.RoleRefNested<N>> implements RoleBindingFluent.RoleRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            RoleRefNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
            RoleRefNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) RoleBindingFluentImpl.this.withRoleRef(builder.build());
    }
    public N endRoleRef(){
            return and();
    }

}
    public class SubjectsNestedImpl<N> extends ObjectReferenceFluentImpl<RoleBindingFluent.SubjectsNested<N>> implements RoleBindingFluent.SubjectsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            SubjectsNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
            SubjectsNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) RoleBindingFluentImpl.this.addToSubjects(builder.build());
    }
    public N endSubject(){
            return and();
    }

}


}
